Exception: Clavis::InvalidHostedDomain

Inherits:
ProviderError show all
Defined in:
lib/clavis/errors.rb

Instance Method Summary collapse

Constructor Details

#initialize(message = "User is not a member of the allowed hosted domain") ⇒ InvalidHostedDomain



64
65
66
# File 'lib/clavis/errors.rb', line 64

def initialize(message = "User is not a member of the allowed hosted domain")
  super
end