Exception: Clavis::UnsupportedGrantType

Inherits:
TokenError show all
Defined in:
lib/clavis/errors.rb

Instance Method Summary collapse

Constructor Details

#initialize(message = "The grant type is not supported by the authorization server") ⇒ UnsupportedGrantType

Returns a new instance of UnsupportedGrantType.



170
171
172
# File 'lib/clavis/errors.rb', line 170

def initialize(message = "The grant type is not supported by the authorization server")
  super
end