Exception: Clavis::InvalidHostedDomain
- Inherits:
-
ProviderError
- Object
- StandardError
- Error
- ProviderError
- Clavis::InvalidHostedDomain
- Defined in:
- lib/clavis/errors.rb
Instance Method Summary collapse
-
#initialize(message = "User is not a member of the allowed hosted domain") ⇒ InvalidHostedDomain
constructor
A new instance of InvalidHostedDomain.
Constructor Details
#initialize(message = "User is not a member of the allowed hosted domain") ⇒ InvalidHostedDomain
64 65 66 |
# File 'lib/clavis/errors.rb', line 64 def initialize( = "User is not a member of the allowed hosted domain") super end |