Exception: Clavis::UnauthorizedClient
- Inherits:
-
TokenError
- Object
- StandardError
- Error
- TokenError
- Clavis::UnauthorizedClient
- Defined in:
- lib/clavis/errors.rb
Instance Method Summary collapse
-
#initialize(message = "The client is not authorized to use this grant type") ⇒ UnauthorizedClient
constructor
A new instance of UnauthorizedClient.
Constructor Details
#initialize(message = "The client is not authorized to use this grant type") ⇒ UnauthorizedClient
Returns a new instance of UnauthorizedClient.
164 165 166 |
# File 'lib/clavis/errors.rb', line 164 def initialize( = "The client is not authorized to use this grant type") super end |