Exception: Clavis::UnsupportedGrantType
- Inherits:
-
TokenError
- Object
- StandardError
- Error
- TokenError
- Clavis::UnsupportedGrantType
- Defined in:
- lib/clavis/errors.rb
Instance Method Summary collapse
-
#initialize(message = "The grant type is not supported by the authorization server") ⇒ UnsupportedGrantType
constructor
A new instance of UnsupportedGrantType.
Constructor Details
#initialize(message = "The grant type is not supported by the authorization server") ⇒ UnsupportedGrantType
Returns a new instance of UnsupportedGrantType.
170 171 172 |
# File 'lib/clavis/errors.rb', line 170 def initialize( = "The grant type is not supported by the authorization server") super end |